#
# spec file for package ghc-syb
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name syb
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.7.2.4
Release:        1.7
Summary:        Scrap Your Boilerplate
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
This package contains the generics system described in the /Scrap Your
Boilerplate/ papers (see <http://www.cs.uu.nl/wiki/GenericProgramming/SYB>).
It defines the 'Data' class of types permitting folding and unfolding of
constructor applications, instances of this class for primitive types, and a
variety of traversals.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc Changelog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun Jul 30 2023 Peter Simons <psimons@suse.com>
- Update syb to version 0.7.2.4.
  [#] 0.7.2.4
  - Improved documentation (thanks to @BinderDavid)
  - Export `ext2` function which was already defined but not exported
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sat Mar 18 2023 Peter Simons <psimons@suse.com>
- Update syb to version 0.7.2.3.
  Upstream has renamed and modified the change log file(s) in this
  release. Unfortunately, the automatic updater cannot reliable
  determine relevant entries for this release.
* Sat Mar 18 2023 Peter Simons <psimons@suse.com>
- Update syb to version 0.7.2.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Sep 17 2022 Peter Simons <psimons@suse.com>
- Update syb to version 0.7.2.2.
  2022-09-17 Sergey Vinokurov <serg.foo@gmail.com>
  * 0.7.2.2: Compatibility with GHC 9.4
  2021-01-20 Sergey Vinokurov <serg.foo@gmail.com>
  * 0.7.2.1: Update cabal version
* Thu Jan 21 2021 psimons@suse.com
- Update syb to version 0.7.2.1.
  2021-01-18 Sergey Vinokurov <serg.foo@gmail.com>
  * 0.7.2: Add compatibility with GHC 9, switch to tasty for tests,
  fix tests on GHCJS
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Mon Jun 17 2019 psimons@suse.com
- Update syb to version 0.7.1.
  Upstream added a new change log file in this release. With no
  previous version to compare against, the automatic updater cannot
  reliable determine the relevante entries for this release.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Wed May 16 2018 psimons@suse.com
- Prefer the new %%license attribute over %%doc.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jul 27 2017 psimons@suse.com
- Update to version 0.7.
* Sat May 27 2017 psimons@suse.com
- Update to version 0.6 revision 1.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.6 revision 0 with cabal2obs.
* Wed Dec 23 2015 mimi.vx@gmail.com
- update to 0.6
* Fri Aug  7 2015 mimi.vx@gmail.com
- update to 0.5.1
* Fri Apr 10 2015 mimi.vx@gmail.com
- update to 0.4.4
  * no changelog available from hackage
* Fri Sep 12 2014 peter.trommler@ohm-hochschule.de
- update to 0.4.1
  * Haskell Platform 2014.2.0.0
  * no changelog available from hackage
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 0.4.0 from upstream
  * fix for ghc 7.7 and up
- part of Haskell Platform 2013.2 update
- more transparent packaging (fewer macros)
* Sun Dec 30 2012 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Tue Oct  2 2012 peter.trommler@ohm-hochschule.de
- update to 0.3.7 from upstream (no changelog)
- required by Haskell Platform 2012.4.0.0
* Sun Jun  3 2012 peter.trommler@ohm-hochschule.de
- update to 0.3.6.1 from upstream (no changelog)
- required by Haskell Platform 2012.2.0.0
* Thu Feb 23 2012 peter.trommler@ohm-hochschule.de
- Added BuildRoot for sle11-sp1
* Wed Dec 28 2011 peter.trommler@ohm-hochschule.de
- Adjusted version for platform 2011.4
* Wed Dec 28 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
